=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-05-25 17:20:51 +0000
+++ bzrlib/builtins.py	2006-05-30 15:18:12 +0000
@@ -25,8 +25,8 @@
 import bzrlib.branch
 from bzrlib.branch import Branch
 import bzrlib.bzrdir as bzrdir
-from bzrlib.changeset.read_changeset import BadChangeset, ChangesetReader
-from bzrlib.changeset.apply_changeset import merge_changeset
+from bzrlib.bundle.read_bundle import BadBundle, BundleReader
+from bzrlib.bundle.apply_bundle import merge_bundle
 from bzrlib.commands import Command, display_command
 import bzrlib.errors as errors
 from bzrlib.errors import (BzrError, BzrCheckError, BzrCommandError, 
@@ -1982,17 +1982,17 @@
         tree = WorkingTree.open_containing(u'.')[0]
         try:
             if branch is not None:
-                reader = ChangesetReader(file(branch, 'rb'))
+                reader = BundleReader(file(branch, 'rb'))
             else:
                 reader = None
         except IOError, e:
             if e.errno not in (errno.ENOENT, errno.EISDIR):
                 raise
             reader = None
-        except BadChangeset:
+        except BadBundle:
             reader = None
         if reader is not None:
-            conflicts = merge_changeset(reader, tree, not force, merge_type,
+            conflicts = merge_bundle(reader, tree, not force, merge_type,
                                         reprocess, show_base)
             if conflicts == 0:
                 return 0
@@ -2479,7 +2479,7 @@
     --dry-run will go through all the motions, but not actually
     remove anything.
     
-    In the future, uncommit will create a changeset, which can then
+    In the future, uncommit will create a revision bundle, which can then
     be re-applied.
     """
 
@@ -2639,7 +2639,7 @@
 # aliases.  ideally we would avoid loading the implementation until the
 # details were needed.
 from bzrlib.conflicts import cmd_resolve, cmd_conflicts, restore
-from bzrlib.changeset.commands import cmd_changeset
+from bzrlib.bundle.commands import cmd_bundle_revisions
 from bzrlib.sign_my_commits import cmd_sign_my_commits
 from bzrlib.weave_commands import cmd_weave_list, cmd_weave_join, \
         cmd_weave_plan_merge, cmd_weave_merge_text

=== renamed directory 'bzrlib/changeset' => 'bzrlib/bundle'
=== renamed file 'bzrlib/changeset/apply_changeset.py' => 'bzrlib/bundle/apply_bundle.py'
--- bzrlib/changeset/apply_changeset.py	2006-05-19 14:13:36 +0000
+++ bzrlib/bundle/apply_bundle.py	2006-05-30 15:18:12 +0000
@@ -1,5 +1,5 @@
 """\
-This contains functionality for installing changesets into repositories
+This contains functionality for installing bundles into repositories
 """
 
 import bzrlib.ui
@@ -8,16 +8,16 @@
 from bzrlib.repository import install_revision
 
 
-def install_changeset(repository, changeset_reader):
+def install_bundle(repository, bundle_reader):
     pb = bzrlib.ui.ui_factory.nested_progress_bar()
     repository.lock_write()
     try:
-        real_revisions = changeset_reader.info.real_revisions
+        real_revisions = bundle_reader.info.real_revisions
         for i, revision in enumerate(reversed(real_revisions)):
             pb.update("Install revisions",i, len(real_revisions))
             if repository.has_revision(revision.revision_id):
                 continue
-            cset_tree = changeset_reader.revision_tree(repository,
+            cset_tree = bundle_reader.revision_tree(repository,
                                                        revision.revision_id)
             install_revision(repository, revision, cset_tree)
     finally:
@@ -25,14 +25,14 @@
         pb.finished()
 
 
-def merge_changeset(reader, tree, check_clean, merge_type, 
+def merge_bundle(reader, tree, check_clean, merge_type, 
                     reprocess, show_base):
-    """Merge a changeset's revision into the current tree."""
+    """Merge a revision bundle into the current tree."""
     pb = bzrlib.ui.ui_factory.nested_progress_bar()
     try:
         pp = ProgressPhase("Merge phase", 6, pb)
         pp.next_phase()
-        install_changeset(tree.branch.repository, reader)
+        install_bundle(tree.branch.repository, reader)
         merger = Merger(tree.branch, this_tree=tree, pb=pb)
         merger.pp = pp
         merger.pp.next_phase()

=== modified file 'bzrlib/bundle/commands.py'
--- bzrlib/changeset/commands.py	2006-05-25 20:30:45 +0000
+++ bzrlib/bundle/commands.py	2006-05-30 15:18:12 +0000
@@ -56,33 +56,33 @@
         send_changeset(b, revision, to, message, file)
 
 
-class cmd_changeset(Command):
-    """Generate a bundled up changeset.
+class cmd_bundle_revisions(Command):
+    """Generate a revision bundle.
 
-    This changeset contains all of the meta-information of a
+    This bundle contains all of the meta-information of a
     diff, rather than just containing the patch information.
 
     You can apply it to another tree using 'bzr merge'.
 
-    bzr cset
-        - Changeset for the last commit
-    bzr cset BASE
-        - Changeset to apply the current tree into BASE
-    bzr cset --revision A
-        - Changeset for revision A
-    bzr cset --revision A..B
-        - Changeset to transform A into B
-    bzr cset --revision A..B BASE
-        - Changeset to transform revision A of BASE into revision B
+    bzr bundle
+        - Bundle for the last commit
+    bzr bundle BASE
+        - Bundle to apply the current tree into BASE
+    bzr bundle --revision A
+        - Bundle for revision A
+    bzr bundle --revision A..B
+        - Bundle to transform A into B
+    bzr bundle --revision A..B BASE
+        - Bundle to transform revision A of BASE into revision B
           of the local tree
     """
     takes_options = ['verbose', 'revision']
     takes_args = ['base?']
-    aliases = ['cset']
+    aliases = ['bundle']
 
     def run(self, base=None, revision=None):
         from bzrlib import user_encoding
-        from bzrlib.changeset.serializer import write_changeset
+        from bzrlib.bundle.serializer import write_bundle
 
         if base is None:
             base_branch = None
@@ -132,8 +132,8 @@
             target_branch.repository.fetch(base_branch.repository, 
                                            revision_id=base_revision)
             del base_branch
-        write_changeset(target_branch.repository, target_revision,
-                        base_revision, sys.stdout)
+        write_bundle(target_branch.repository, target_revision, base_revision,
+                     sys.stdout)
 
 
 class cmd_verify_changeset(Command):

=== modified file 'bzrlib/bundle/common.py'
--- bzrlib/changeset/common.py	2006-05-26 13:50:01 +0000
+++ bzrlib/bundle/common.py	2006-05-30 15:18:12 +0000
@@ -1,11 +1,11 @@
 #!/usr/bin/env python
 """\
-Common entries, like strings, etc, for the changeset reading + writing code.
+Common entries, like strings, etc, for the bundle reading + writing code.
 """
 
 import bzrlib
 
-header_str = 'Bazaar changeset v'
+header_str = 'Bazaar revision bundle v'
 version = (0, 7)
 
 

=== renamed file 'bzrlib/changeset/read_changeset.py' => 'bzrlib/bundle/read_bundle.py'
--- bzrlib/changeset/read_changeset.py	2006-05-26 13:50:01 +0000
+++ bzrlib/bundle/read_bundle.py	2006-05-30 15:18:12 +0000
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 """\
-Read in a changeset output, and process it into a Changeset object.
+Read in a bundle stream, and process it into a BundleReader object.
 """
 
 import base64
@@ -9,7 +9,7 @@
 import pprint
 
 from bzrlib.errors import TestamentMismatch, BzrError
-from bzrlib.changeset.common import get_header, header_str
+from bzrlib.bundle.common import get_header, header_str
 from bzrlib.inventory import (Inventory, InventoryEntry,
                               InventoryDirectory, InventoryFile,
                               InventoryLink)
@@ -21,10 +21,10 @@
 from bzrlib.xml5 import serializer_v5
 
 
-class BadChangeset(Exception): pass
-class MalformedHeader(BadChangeset): pass
-class MalformedPatches(BadChangeset): pass
-class MalformedFooter(BadChangeset): pass
+class BadBundle(Exception): pass
+class MalformedHeader(BadBundle): pass
+class MalformedPatches(BadBundle): pass
+class MalformedFooter(BadBundle): pass
 
 
 class RevisionInfo(object):
@@ -70,7 +70,7 @@
         return rev
 
 
-class ChangesetInfo(object):
+class BundleInfo(object):
     """This contains the meta information. Stuff that allows you to
     recreate the revision or inventory XML.
     """
@@ -99,7 +99,7 @@
         split up, based on the assumptions that can be made
         when information is missing.
         """
-        from bzrlib.changeset.common import unpack_highres_date
+        from bzrlib.bundle.common import unpack_highres_date
         # Put in all of the guessable information.
         if not self.timestamp and self.date:
             self.timestamp, self.timezone = unpack_highres_date(self.date)
@@ -158,12 +158,12 @@
         raise KeyError(revision_id)
 
 
-class ChangesetReader(object):
-    """This class reads in a changeset from a file, and returns
-    a Changeset object, which can then be applied against a tree.
+class BundleReader(object):
+    """This class reads in a bundle from a file, and returns
+    a Bundle object, which can then be applied against a tree.
     """
     def __init__(self, from_file):
-        """Read in the changeset from the file.
+        """Read in the bundle from the file.
 
         :param from_file: A file-like object (must have iterator support).
         """
@@ -171,11 +171,11 @@
         self.from_file = iter(from_file)
         self._next_line = None
         
-        self.info = ChangesetInfo()
+        self.info = BundleInfo()
         # We put the actual inventory ids in the footer, so that the patch
         # is easier to read for humans.
         # Unfortunately, that means we need to read everything before we
-        # can create a proper changeset.
+        # can create a proper bundle.
         self._read()
         self._validate()
 
@@ -256,7 +256,7 @@
                 local_sha1 = testament.as_sha1()
                 if sha1 != local_sha1:
                     raise BzrError('sha1 mismatch. For revision id {%s}' 
-                            'local: %s, cset: %s' % (revision_id, local_sha1, sha1))
+                            'local: %s, bundle: %s' % (revision_id, local_sha1, sha1))
                 else:
                     count += 1
             elif revision_id not in checked:
@@ -272,7 +272,8 @@
                 local_sha1 = repository.get_inventory_sha1(inv_id)
                 if sha1 != local_sha1:
                     raise BzrError('sha1 mismatch. For inventory id {%s}' 
-                            'local: %s, cset: %s' % (inv_id, local_sha1, sha1))
+                                   'local: %s, bundle: %s' % 
+                                   (inv_id, local_sha1, sha1))
                 else:
                     count += 1
 
@@ -280,10 +281,10 @@
             # I don't know if this is an error yet
             warning('Not all revision hashes could be validated.'
                     ' Unable validate %d hashes' % len(missing))
-        mutter('Verified %d sha hashes for the changeset.' % count)
+        mutter('Verified %d sha hashes for the bundle.' % count)
 
     def _validate_inventory(self, inv, revision_id):
-        """At this point we should have generated the ChangesetTree,
+        """At this point we should have generated the BundleTree,
         so build up an inventory, and make sure the hashes match.
         """
 
@@ -300,8 +301,8 @@
             warning('Inventory sha hash mismatch for revision %s. %s'
                     ' != %s' % (revision_id, sha1, rev.inventory_sha1))
 
-    def get_changeset(self, repository):
-        """Return the meta information, and a Changeset tree which can
+    def get_bundle(self, repository):
+        """Return the meta information, and a Bundle tree which can
         be used to populate the local stores and working tree, respectively.
         """
         return self.info, self.revision_tree(repository, self.info.target)
@@ -313,15 +314,15 @@
         self._validate_references_from_repository(repository)
         revision_info = self.info.get_revision_info(revision_id)
         inventory_revision_id = revision_id
-        cset_tree = ChangesetTree(repository.revision_tree(base), 
+        bundle_tree = BundleTree(repository.revision_tree(base), 
                                   inventory_revision_id)
-        self._update_tree(cset_tree, revision_id)
+        self._update_tree(bundle_tree, revision_id)
 
-        inv = cset_tree.inventory
+        inv = bundle_tree.inventory
         self._validate_inventory(inv, revision_id)
         self._validate_revision(inv, revision_id)
 
-        return cset_tree
+        return bundle_tree
 
     def _next(self):
         """yield the next line, but secretly
@@ -500,11 +501,11 @@
             if self._next_line is None:
                 break
 
-    def _update_tree(self, cset_tree, revision_id):
-        """This fills out a ChangesetTree based on the information
+    def _update_tree(self, bundle_tree, revision_id):
+        """This fills out a BundleTree based on the information
         that was read in.
 
-        :param cset_tree: A ChangesetTree to update with the new information.
+        :param bundle_tree: A BundleTree to update with the new information.
         """
 
         def get_rev_id(last_changed, path, kind):
@@ -512,7 +513,7 @@
                 changed_revision_id = last_changed.decode('utf-8')
             else:
                 changed_revision_id = revision_id
-            cset_tree.note_last_changed(path, changed_revision_id)
+            bundle_tree.note_last_changed(path, changed_revision_id)
             return changed_revision_id
 
         def extra_info(info, new_path):
@@ -528,9 +529,9 @@
                 elif name == 'executable':
                     assert value in ('yes', 'no'), value
                     val = (value == 'yes')
-                    cset_tree.note_executable(new_path, val)
+                    bundle_tree.note_executable(new_path, val)
                 elif name == 'target':
-                    cset_tree.note_target(new_path, value)
+                    bundle_tree.note_target(new_path, value)
                 elif name == 'encoding':
                     encoding = value
             return last_changed, encoding
@@ -541,7 +542,7 @@
                 patch = base64.decodestring(''.join(lines))
             else:
                 patch =  ''.join(lines)
-            cset_tree.note_patch(path, patch)
+            bundle_tree.note_patch(path, patch)
 
         def renamed(kind, extra, lines):
             info = extra.split(' // ')
@@ -554,7 +555,7 @@
             else:
                 new_path = info[1]
 
-            cset_tree.note_rename(old_path, new_path)
+            bundle_tree.note_rename(old_path, new_path)
             last_modified, encoding = extra_info(info[2:], new_path)
             revision = get_rev_id(last_modified, new_path, kind)
             if lines:
@@ -568,7 +569,7 @@
                 raise BzrError('removed action lines should only have the path'
                         ': %r' % extra)
             path = info[0]
-            cset_tree.note_deletion(path)
+            bundle_tree.note_deletion(path)
 
         def added(kind, extra, lines):
             info = extra.split(' // ')
@@ -584,9 +585,9 @@
                         ': %r' % extra)
             file_id = info[1][8:]
 
-            cset_tree.note_id(file_id, path, kind)
+            bundle_tree.note_id(file_id, path, kind)
             # this will be overridden in extra_info if executable is specified.
-            cset_tree.note_executable(path, False)
+            bundle_tree.note_executable(path, False)
             last_changed, encoding = extra_info(info[2:], path)
             revision = get_rev_id(last_changed, path, kind)
             if kind == 'directory':
@@ -634,20 +635,7 @@
             valid_actions[action](kind, extra, lines)
 
 
-def read_changeset(from_file, repository):
-    """Read in a changeset from a iterable object (such as a file object)
-
-    :param from_file: A file-like object to read the changeset information.
-    :param repository: This will be used to build the changeset tree, it needs
-                       to contain the base of the changeset. (Which you
-                       probably won't know about until after the changeset is
-                       parsed.)
-    """
-    cr = ChangesetReader(from_file)
-    return cr.get_changeset(repository)
-
-
-class ChangesetTree(Tree):
+class BundleTree(Tree):
     def __init__(self, base_tree, revision_id):
         self.base_tree = base_tree
         self._renamed = {} # Mapping from old_path => new_path
@@ -862,7 +850,7 @@
         return len(content), sha_string(content)
 
     def _get_inventory(self):
-        """Build up the inventory entry for the ChangesetTree.
+        """Build up the inventory entry for the BundleTree.
 
         This need to be called before ever accessing self.inventory
         """

=== modified file 'bzrlib/bundle/serializer/__init__.py'
--- bzrlib/changeset/serializer/__init__.py	2006-05-19 20:37:09 +0000
+++ bzrlib/bundle/serializer/__init__.py	2006-05-30 15:18:12 +0000
@@ -14,7 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-"""Serializer factory for reading and writing changesets.
+"""Serializer factory for reading and writing bundles.
 """
 
 import base64
@@ -25,9 +25,9 @@
 from bzrlib.diff import internal_diff
 from bzrlib.revision import NULL_REVISION
 
-# New changesets should try to use this header format
-CHANGESET_HEADER = '# Bazaar changeset v'
-CHANGESET_HEADER_RE = re.compile(r'^# Bazaar changeset v(?P<version>\d+[\w.]*)\n$')
+# New bundles should try to use this header format
+BUNDLE_HEADER = '# Bazaar revision bundle v'
+BUNDLE_HEADER_RE = re.compile(r'^# Bazaar revision bundle v(?P<version>\d+[\w.]*)\n$')
 CHANGESET_OLD_HEADER_RE = re.compile(r'^# Bazaar-NG changeset v(?P<version>\d+[\w.]*)\n$')
 
 
@@ -41,28 +41,28 @@
 
 
 def read(f):
-    """Read in a changeset from a filelike object.
+    """Read in a bundle from a filelike object.
 
     :param f: A file-like object
-    :return: A list of Changeset objects
+    :return: A list of Bundle objects
     """
     version = None
     for line in f:
-        m = CHANGESET_HEADER_RE.match(line)
+        m = BUNDLE_HEADER_RE.match(line)
         if m:
             version = m.group('version')
             break
         m = CHANGESET_OLD_HEADER_RE.match(line)
         if m:
             version = m.group('version')
-            raise errors.ChangesetNotSupported(version, 'old format changesets not supported')
+            raise errors.BundleNotSupported(version, 'old format bundles not supported')
 
     if version is None:
-        raise errors.NoChangesetFound(_get_filename(f))
+        raise errors.NoBundleFound(_get_filename(f))
 
-    # Now we have a version, to figure out how to read the changeset
+    # Now we have a version, to figure out how to read the bundle 
     if not _serializers.has_key(version):
-        raise errors.ChangesetNotSupported(version, 'version not listed in known versions')
+        raise errors.BundleNotSupported(version, 'version not listed in known versions')
 
     serializer = _serializers[version](version)
 
@@ -70,7 +70,7 @@
 
 
 def write(source, revision_ids, f, version=None, forced_bases={}):
-    """Serialize a list of changesets to a filelike object.
+    """Serialize a list of bundles to a filelike object.
 
     :param source: A source for revision information
     :param revision_ids: The list of revision ids to serialize
@@ -79,13 +79,13 @@
     """
 
     if not _serializers.has_key(version):
-        raise errors.ChangesetNotSupported(version, 'unknown changeset format')
+        raise errors.BundleNotSupported(version, 'unknown bundle format')
 
     serializer = _serializers[version](version)
     return serializer.write(source, revision_ids, forced_bases, f) 
 
 
-def write_changeset(repository, revision_id, base_revision_id, out):
+def write_bundle(repository, revision_id, base_revision_id, out):
     """"""
     if base_revision_id is NULL_REVISION:
         base_revision_id = None
@@ -194,7 +194,7 @@
     return (timestamp, offset)
 
 
-class ChangesetSerializer(object):
+class BundleSerializer(object):
     """The base class for Serializers.
 
     Common functionality should be included here.
@@ -203,15 +203,15 @@
         self.version = version
 
     def read(self, f):
-        """Read the rest of the changesets from the supplied file.
+        """Read the rest of the bundles from the supplied file.
 
         :param f: The file to read from
-        :return: A list of changeset trees
+        :return: A list of bundle trees
         """
         raise NotImplementedError
 
     def write(self, source, revision_ids, forced_bases, f):
-        """Write the changesets to the supplied files.
+        """Write the bundle to the supplied file.
 
         :param source: A source for revision information
         :param revision_ids: The list of revision ids to serialize
@@ -222,7 +222,7 @@
 
 
 def register(version, klass, overwrite=False):
-    """Register a ChangesetSerializer version.
+    """Register a BundleSerializer version.
 
     :param version: The version associated with this format
     :param klass: The class to instantiate, which must take a version argument
@@ -237,7 +237,7 @@
 
 
 def register_lazy(version, module, classname, overwrite=False):
-    """Register lazy-loaded changeset serializer.
+    """Register lazy-loaded bundle serializer.
 
     :param version: The version associated with this reader
     :param module: String indicating what module should be loaded
@@ -259,6 +259,6 @@
     base64.encode(temp, to_file)
     to_file.write('\n')
 
-register_lazy('0.7', 'bzrlib.changeset.serializer.v07', 'ChangesetSerializerV07')
-register_lazy(None, 'bzrlib.changeset.serializer.v07', 'ChangesetSerializerV07')
+register_lazy('0.7', 'bzrlib.bundle.serializer.v07', 'BundleSerializerV07')
+register_lazy(None, 'bzrlib.bundle.serializer.v07', 'BundleSerializerV07')
 

=== modified file 'bzrlib/bundle/serializer/v07.py'
--- bzrlib/changeset/serializer/v07.py	2006-05-25 17:13:14 +0000
+++ bzrlib/bundle/serializer/v07.py	2006-05-30 15:18:12 +0000
@@ -14,15 +14,17 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-"""Serializer factory for reading and writing changesets.
+"""Serializer factory for reading and writing bundles.
 """
 
 import os
 
-from bzrlib.changeset.serializer import (ChangesetSerializer, 
-        CHANGESET_HEADER,
-        format_highres_date, unpack_highres_date)
-from bzrlib.changeset.serializer import binary_diff
+from bzrlib.bundle.serializer import (BundleSerializer, 
+                                      BUNDLE_HEADER, 
+                                      format_highres_date,
+                                      unpack_highres_date,
+                                     )
+from bzrlib.bundle.serializer import binary_diff
 from bzrlib.delta import compare_trees
 from bzrlib.diff import internal_diff
 import bzrlib.errors as errors
@@ -82,19 +84,19 @@
         to_file.write(text_line+'\n')
 
 
-class ChangesetSerializerV07(ChangesetSerializer):
+class BundleSerializerV07(BundleSerializer):
     def read(self, f):
-        """Read the rest of the changesets from the supplied file.
+        """Read the rest of the bundles from the supplied file.
 
         :param f: The file to read from
-        :return: A list of changesets
+        :return: A list of bundles
         """
         assert self.version == '0.7'
         # The first line of the header should have been read
         raise NotImplementedError
 
     def write(self, source, revision_ids, forced_bases, f):
-        """Write the changesets to the supplied files.
+        """Write the bundless to the supplied files.
 
         :param source: A source for revision information
         :param revision_ids: The list of revision ids to serialize
@@ -120,7 +122,7 @@
     def _write_main_header(self):
         """Write the header for the changes"""
         f = self.to_file
-        f.write(CHANGESET_HEADER)
+        f.write(BUNDLE_HEADER)
         f.write('0.7\n')
         f.write('#\n')
 

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-05-30 03:39:31 +0000
+++ bzrlib/errors.py	2006-05-30 15:18:12 +0000
@@ -747,15 +747,15 @@
     """
 
 
-class NoChangesetFound(BzrNewError):
-    """No changeset was found in %(filename)s"""
+class NoBundleFound(BzrNewError):
+    """No bundle was found in %(filename)s"""
     def __init__(self, filename):
         BzrNewError.__init__(self)
         self.filename = filename
 
 
-class ChangesetNotSupported(BzrNewError):
-    """Unable to handle changeset version %(version)s: %(msg)s"""
+class BundleNotSupported(BzrNewError):
+    """Unable to handle bundle version %(version)s: %(msg)s"""
     def __init__(self, version, msg):
         BzrNewError.__init__(self)
         self.version = version

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-05-25 17:20:51 +0000
+++ bzrlib/tests/__init__.py	2006-05-30 15:18:12 +0000
@@ -43,7 +43,7 @@
 import bzrlib.branch
 import bzrlib.bzrdir as bzrdir
 import bzrlib.commands
-import bzrlib.changeset.serializer
+import bzrlib.bundle.serializer
 import bzrlib.errors as errors
 import bzrlib.inventory
 import bzrlib.iterablefile
@@ -76,7 +76,7 @@
 MODULES_TO_TEST = []
 MODULES_TO_DOCTEST = [
                       bzrlib.branch,
-                      bzrlib.changeset.serializer,
+                      bzrlib.bundle.serializer,
                       bzrlib.commands,
                       bzrlib.errors,
                       bzrlib.inventory,
@@ -1118,8 +1118,8 @@
                    'bzrlib.tests.test_api',
                    'bzrlib.tests.test_bad_files',
                    'bzrlib.tests.test_branch',
+                   'bzrlib.tests.test_bundle',
                    'bzrlib.tests.test_bzrdir',
-                   'bzrlib.tests.test_changeset',
                    'bzrlib.tests.test_command',
                    'bzrlib.tests.test_commit',
                    'bzrlib.tests.test_commit_merge',

=== modified file 'bzrlib/tests/blackbox/test_merge.py'
--- bzrlib/tests/blackbox/test_merge.py	2006-05-14 15:36:25 +0000
+++ bzrlib/tests/blackbox/test_merge.py	2006-05-30 15:18:12 +0000
@@ -168,9 +168,7 @@
         tree_b = branch_b.bzrdir.open_workingtree()
         tree_b.commit('merge branch_c')
 
-    def test_merge_changeset(self):
-        # Changesets actually represent a revision (plus its ancestors), so
-        # they can be merged.
+    def test_merge_bundle(self):
         from bzrlib.testament import Testament
         tree_a = self.make_branch_and_tree('branch_a')
         f = file('branch_a/a', 'wb')
@@ -190,9 +188,9 @@
         f.close()
         tree_b.commit('message')
         os.chdir('branch_b')
-        file('../cset', 'wb').write(self.runbzr('changeset ../branch_a')[0])
+        file('../bundle', 'wb').write(self.runbzr('bundle ../branch_a')[0])
         os.chdir('../branch_a')
-        self.runbzr('merge ../cset', retcode=1)
+        self.runbzr('merge ../bundle', retcode=1)
         testament_a = Testament.from_revision(tree_a.branch.repository, 
                                               tree_b.last_revision())
         testament_b = Testament.from_revision(tree_b.branch.repository,

=== renamed file 'bzrlib/tests/test_changeset.py' => 'bzrlib/tests/test_bundle.py'
--- bzrlib/tests/test_changeset.py	2006-05-25 16:40:18 +0000
+++ bzrlib/tests/test_bundle.py	2006-05-30 15:18:12 +0000
@@ -16,11 +16,11 @@
 
 from StringIO import StringIO
 
-from bzrlib.builtins import merge_changeset, merge
+from bzrlib.builtins import merge
 from bzrlib.bzrdir import BzrDir
-from bzrlib.changeset.apply_changeset import install_changeset
-from bzrlib.changeset.read_changeset import ChangesetTree, ChangesetReader
-from bzrlib.changeset.serializer import write_changeset
+from bzrlib.bundle.apply_bundle import install_bundle, merge_bundle
+from bzrlib.bundle.read_bundle import BundleTree, BundleReader
+from bzrlib.bundle.serializer import write_bundle
 from bzrlib.diff import internal_diff
 from bzrlib.errors import BzrError, TestamentMismatch
 from bzrlib.merge import Merge3Merger
@@ -118,8 +118,8 @@
         return text_sha1, len(self.contents[file_id])
 
 
-class CTreeTester(TestCase):
-    """A simple unittest tester for the ChangesetTree class."""
+class BTreeTester(TestCase):
+    """A simple unittest tester for the BundleTree class."""
 
     def make_tree_1(self):
         mtree = MockTree()
@@ -127,77 +127,78 @@
         mtree.add_dir("b", "grandparent/parent")
         mtree.add_file("c", "grandparent/parent/file", "Hello\n")
         mtree.add_dir("d", "grandparent/alt_parent")
-        return ChangesetTree(mtree, ''), mtree
+        return BundleTree(mtree, ''), mtree
         
     def test_renames(self):
         """Ensure that file renames have the proper effect on children"""
-        ctree = self.make_tree_1()[0]
-        self.assertEqual(ctree.old_path("grandparent"), "grandparent")
-        self.assertEqual(ctree.old_path("grandparent/parent"), "grandparent/parent")
-        self.assertEqual(ctree.old_path("grandparent/parent/file"),
-            "grandparent/parent/file")
-
-        self.assertEqual(ctree.id2path("a"), "grandparent")
-        self.assertEqual(ctree.id2path("b"), "grandparent/parent")
-        self.assertEqual(ctree.id2path("c"), "grandparent/parent/file")
-
-        self.assertEqual(ctree.path2id("grandparent"), "a")
-        self.assertEqual(ctree.path2id("grandparent/parent"), "b")
-        self.assertEqual(ctree.path2id("grandparent/parent/file"), "c")
-
-        assert ctree.path2id("grandparent2") is None
-        assert ctree.path2id("grandparent2/parent") is None
-        assert ctree.path2id("grandparent2/parent/file") is None
-
-        ctree.note_rename("grandparent", "grandparent2")
-        assert ctree.old_path("grandparent") is None
-        assert ctree.old_path("grandparent/parent") is None
-        assert ctree.old_path("grandparent/parent/file") is None
-
-        self.assertEqual(ctree.id2path("a"), "grandparent2")
-        self.assertEqual(ctree.id2path("b"), "grandparent2/parent")
-        self.assertEqual(ctree.id2path("c"), "grandparent2/parent/file")
-
-        self.assertEqual(ctree.path2id("grandparent2"), "a")
-        self.assertEqual(ctree.path2id("grandparent2/parent"), "b")
-        self.assertEqual(ctree.path2id("grandparent2/parent/file"), "c")
-
-        assert ctree.path2id("grandparent") is None
-        assert ctree.path2id("grandparent/parent") is None
-        assert ctree.path2id("grandparent/parent/file") is None
-
-        ctree.note_rename("grandparent/parent", "grandparent2/parent2")
-        self.assertEqual(ctree.id2path("a"), "grandparent2")
-        self.assertEqual(ctree.id2path("b"), "grandparent2/parent2")
-        self.assertEqual(ctree.id2path("c"), "grandparent2/parent2/file")
-
-        self.assertEqual(ctree.path2id("grandparent2"), "a")
-        self.assertEqual(ctree.path2id("grandparent2/parent2"), "b")
-        self.assertEqual(ctree.path2id("grandparent2/parent2/file"), "c")
-
-        assert ctree.path2id("grandparent2/parent") is None
-        assert ctree.path2id("grandparent2/parent/file") is None
-
-        ctree.note_rename("grandparent/parent/file", 
+        btree = self.make_tree_1()[0]
+        self.assertEqual(btree.old_path("grandparent"), "grandparent")
+        self.assertEqual(btree.old_path("grandparent/parent"), 
+                         "grandparent/parent")
+        self.assertEqual(btree.old_path("grandparent/parent/file"),
+                         "grandparent/parent/file")
+
+        self.assertEqual(btree.id2path("a"), "grandparent")
+        self.assertEqual(btree.id2path("b"), "grandparent/parent")
+        self.assertEqual(btree.id2path("c"), "grandparent/parent/file")
+
+        self.assertEqual(btree.path2id("grandparent"), "a")
+        self.assertEqual(btree.path2id("grandparent/parent"), "b")
+        self.assertEqual(btree.path2id("grandparent/parent/file"), "c")
+
+        assert btree.path2id("grandparent2") is None
+        assert btree.path2id("grandparent2/parent") is None
+        assert btree.path2id("grandparent2/parent/file") is None
+
+        btree.note_rename("grandparent", "grandparent2")
+        assert btree.old_path("grandparent") is None
+        assert btree.old_path("grandparent/parent") is None
+        assert btree.old_path("grandparent/parent/file") is None
+
+        self.assertEqual(btree.id2path("a"), "grandparent2")
+        self.assertEqual(btree.id2path("b"), "grandparent2/parent")
+        self.assertEqual(btree.id2path("c"), "grandparent2/parent/file")
+
+        self.assertEqual(btree.path2id("grandparent2"), "a")
+        self.assertEqual(btree.path2id("grandparent2/parent"), "b")
+        self.assertEqual(btree.path2id("grandparent2/parent/file"), "c")
+
+        assert btree.path2id("grandparent") is None
+        assert btree.path2id("grandparent/parent") is None
+        assert btree.path2id("grandparent/parent/file") is None
+
+        btree.note_rename("grandparent/parent", "grandparent2/parent2")
+        self.assertEqual(btree.id2path("a"), "grandparent2")
+        self.assertEqual(btree.id2path("b"), "grandparent2/parent2")
+        self.assertEqual(btree.id2path("c"), "grandparent2/parent2/file")
+
+        self.assertEqual(btree.path2id("grandparent2"), "a")
+        self.assertEqual(btree.path2id("grandparent2/parent2"), "b")
+        self.assertEqual(btree.path2id("grandparent2/parent2/file"), "c")
+
+        assert btree.path2id("grandparent2/parent") is None
+        assert btree.path2id("grandparent2/parent/file") is None
+
+        btree.note_rename("grandparent/parent/file", 
                           "grandparent2/parent2/file2")
-        self.assertEqual(ctree.id2path("a"), "grandparent2")
-        self.assertEqual(ctree.id2path("b"), "grandparent2/parent2")
-        self.assertEqual(ctree.id2path("c"), "grandparent2/parent2/file2")
-
-        self.assertEqual(ctree.path2id("grandparent2"), "a")
-        self.assertEqual(ctree.path2id("grandparent2/parent2"), "b")
-        self.assertEqual(ctree.path2id("grandparent2/parent2/file2"), "c")
-
-        assert ctree.path2id("grandparent2/parent2/file") is None
+        self.assertEqual(btree.id2path("a"), "grandparent2")
+        self.assertEqual(btree.id2path("b"), "grandparent2/parent2")
+        self.assertEqual(btree.id2path("c"), "grandparent2/parent2/file2")
+
+        self.assertEqual(btree.path2id("grandparent2"), "a")
+        self.assertEqual(btree.path2id("grandparent2/parent2"), "b")
+        self.assertEqual(btree.path2id("grandparent2/parent2/file2"), "c")
+
+        assert btree.path2id("grandparent2/parent2/file") is None
 
     def test_moves(self):
         """Ensure that file moves have the proper effect on children"""
-        ctree = self.make_tree_1()[0]
-        ctree.note_rename("grandparent/parent/file", 
+        btree = self.make_tree_1()[0]
+        btree.note_rename("grandparent/parent/file", 
                           "grandparent/alt_parent/file")
-        self.assertEqual(ctree.id2path("c"), "grandparent/alt_parent/file")
-        self.assertEqual(ctree.path2id("grandparent/alt_parent/file"), "c")
-        assert ctree.path2id("grandparent/parent/file") is None
+        self.assertEqual(btree.id2path("c"), "grandparent/alt_parent/file")
+        self.assertEqual(btree.path2id("grandparent/alt_parent/file"), "c")
+        assert btree.path2id("grandparent/parent/file") is None
 
     def unified_diff(self, old, new):
         out = StringIO()
@@ -206,76 +207,76 @@
         return out.read()
 
     def make_tree_2(self):
-        ctree = self.make_tree_1()[0]
-        ctree.note_rename("grandparent/parent/file", 
+        btree = self.make_tree_1()[0]
+        btree.note_rename("grandparent/parent/file", 
                           "grandparent/alt_parent/file")
-        assert ctree.id2path("e") is None
-        assert ctree.path2id("grandparent/parent/file") is None
-        ctree.note_id("e", "grandparent/parent/file")
-        return ctree
+        assert btree.id2path("e") is None
+        assert btree.path2id("grandparent/parent/file") is None
+        btree.note_id("e", "grandparent/parent/file")
+        return btree
 
     def test_adds(self):
         """File/inventory adds"""
-        ctree = self.make_tree_2()
+        btree = self.make_tree_2()
         add_patch = self.unified_diff([], ["Extra cheese\n"])
-        ctree.note_patch("grandparent/parent/file", add_patch)
-        ctree.note_id('f', 'grandparent/parent/symlink', kind='symlink')
-        ctree.note_target('grandparent/parent/symlink', 'venus')
-        self.adds_test(ctree)
+        btree.note_patch("grandparent/parent/file", add_patch)
+        btree.note_id('f', 'grandparent/parent/symlink', kind='symlink')
+        btree.note_target('grandparent/parent/symlink', 'venus')
+        self.adds_test(btree)
 
-    def adds_test(self, ctree):
-        self.assertEqual(ctree.id2path("e"), "grandparent/parent/file")
-        self.assertEqual(ctree.path2id("grandparent/parent/file"), "e")
-        self.assertEqual(ctree.get_file("e").read(), "Extra cheese\n")
-        self.assertEqual(ctree.get_symlink_target('f'), 'venus')
+    def adds_test(self, btree):
+        self.assertEqual(btree.id2path("e"), "grandparent/parent/file")
+        self.assertEqual(btree.path2id("grandparent/parent/file"), "e")
+        self.assertEqual(btree.get_file("e").read(), "Extra cheese\n")
+        self.assertEqual(btree.get_symlink_target('f'), 'venus')
 
     def test_adds2(self):
         """File/inventory adds, with patch-compatibile renames"""
-        ctree = self.make_tree_2()
-        ctree.contents_by_id = False
+        btree = self.make_tree_2()
+        btree.contents_by_id = False
         add_patch = self.unified_diff(["Hello\n"], ["Extra cheese\n"])
-        ctree.note_patch("grandparent/parent/file", add_patch)
-        ctree.note_id('f', 'grandparent/parent/symlink', kind='symlink')
-        ctree.note_target('grandparent/parent/symlink', 'venus')
-        self.adds_test(ctree)
+        btree.note_patch("grandparent/parent/file", add_patch)
+        btree.note_id('f', 'grandparent/parent/symlink', kind='symlink')
+        btree.note_target('grandparent/parent/symlink', 'venus')
+        self.adds_test(btree)
 
     def make_tree_3(self):
-        ctree, mtree = self.make_tree_1()
+        btree, mtree = self.make_tree_1()
         mtree.add_file("e", "grandparent/parent/topping", "Anchovies\n")
-        ctree.note_rename("grandparent/parent/file", 
+        btree.note_rename("grandparent/parent/file", 
                           "grandparent/alt_parent/file")
-        ctree.note_rename("grandparent/parent/topping", 
+        btree.note_rename("grandparent/parent/topping", 
                           "grandparent/alt_parent/stopping")
-        return ctree
+        return btree
 
-    def get_file_test(self, ctree):
-        self.assertEqual(ctree.get_file("e").read(), "Lemon\n")
-        self.assertEqual(ctree.get_file("c").read(), "Hello\n")
+    def get_file_test(self, btree):
+        self.assertEqual(btree.get_file("e").read(), "Lemon\n")
+        self.assertEqual(btree.get_file("c").read(), "Hello\n")
 
     def test_get_file(self):
         """Get file contents"""
-        ctree = self.make_tree_3()
+        btree = self.make_tree_3()
         mod_patch = self.unified_diff(["Anchovies\n"], ["Lemon\n"])
-        ctree.note_patch("grandparent/alt_parent/stopping", mod_patch)
-        self.get_file_test(ctree)
+        btree.note_patch("grandparent/alt_parent/stopping", mod_patch)
+        self.get_file_test(btree)
 
     def test_get_file2(self):
         """Get file contents, with patch-compatibile renames"""
-        ctree = self.make_tree_3()
-        ctree.contents_by_id = False
+        btree = self.make_tree_3()
+        btree.contents_by_id = False
         mod_patch = self.unified_diff([], ["Lemon\n"])
-        ctree.note_patch("grandparent/alt_parent/stopping", mod_patch)
+        btree.note_patch("grandparent/alt_parent/stopping", mod_patch)
         mod_patch = self.unified_diff([], ["Hello\n"])
-        ctree.note_patch("grandparent/alt_parent/file", mod_patch)
-        self.get_file_test(ctree)
+        btree.note_patch("grandparent/alt_parent/file", mod_patch)
+        self.get_file_test(btree)
 
     def test_delete(self):
-        "Deletion by changeset"
-        ctree = self.make_tree_1()[0]
-        self.assertEqual(ctree.get_file("c").read(), "Hello\n")
-        ctree.note_deletion("grandparent/parent/file")
-        assert ctree.id2path("c") is None
-        assert ctree.path2id("grandparent/parent/file") is None
+        "Deletion by bundle"
+        btree = self.make_tree_1()[0]
+        self.assertEqual(btree.get_file("c").read(), "Hello\n")
+        btree.note_deletion("grandparent/parent/file")
+        assert btree.id2path("c") is None
+        assert btree.path2id("grandparent/parent/file") is None
 
     def sorted_ids(self, tree):
         ids = list(tree)
@@ -284,80 +285,84 @@
 
     def test_iteration(self):
         """Ensure that iteration through ids works properly"""
-        ctree = self.make_tree_1()[0]
-        self.assertEqual(self.sorted_ids(ctree), ['a', 'b', 'c', 'd'])
-        ctree.note_deletion("grandparent/parent/file")
-        ctree.note_id("e", "grandparent/alt_parent/fool", kind="directory")
-        ctree.note_last_changed("grandparent/alt_parent/fool", 
+        btree = self.make_tree_1()[0]
+        self.assertEqual(self.sorted_ids(btree), ['a', 'b', 'c', 'd'])
+        btree.note_deletion("grandparent/parent/file")
+        btree.note_id("e", "grandparent/alt_parent/fool", kind="directory")
+        btree.note_last_changed("grandparent/alt_parent/fool", 
                                 "revisionidiguess")
-        self.assertEqual(self.sorted_ids(ctree), ['a', 'b', 'd', 'e'])
+        self.assertEqual(self.sorted_ids(btree), ['a', 'b', 'd', 'e'])
 
 
 class CSetTester(TestCaseInTempDir):
 
-    def get_valid_cset(self, base_rev_id, rev_id,
-            checkout_dir=None, message=None):
-        """Create a changeset from base_rev_id -> rev_id in built-in branch.
+    def get_valid_bundle(self, base_rev_id, rev_id, checkout_dir=None,
+                         message=None):
+        """Create a bundle from base_rev_id -> rev_id in built-in branch.
         Make sure that the text generated is valid, and that it
         can be applied against the base, and generate the same information.
         
-        :return: The in-memory changeset
+        :return: The in-memory bundle 
         """
         from cStringIO import StringIO
 
-        cset_txt = StringIO()
-        rev_ids = write_changeset(self.b1.repository, rev_id, base_rev_id, 
-                                  cset_txt)
-        cset_txt.seek(0)
-        self.assertEqual(cset_txt.readline(), '# Bazaar changeset v0.7\n')
-        self.assertEqual(cset_txt.readline(), '#\n')
+        bundle_txt = StringIO()
+        rev_ids = write_bundle(self.b1.repository, rev_id, base_rev_id, 
+                               bundle_txt)
+        bundle_txt.seek(0)
+        self.assertEqual(bundle_txt.readline(), 
+                         '# Bazaar revision bundle v0.7\n')
+        self.assertEqual(bundle_txt.readline(), '#\n')
 
         rev = self.b1.repository.get_revision(rev_id)
-        self.assertEqual(cset_txt.readline().decode('utf-8'),
-                u'# message:\n')
+        self.assertEqual(bundle_txt.readline().decode('utf-8'),
+                         u'# message:\n')
 
-        open(',,cset', 'wb').write(cset_txt.getvalue())
-        cset_txt.seek(0)
-        # This should also validate the generate changeset
-        cset = ChangesetReader(cset_txt)
-        for cset_rev in cset.info.real_revisions:
-            # These really should have already been checked in read_changeset
-            # since it computes the sha1 hash for the revision, which
-            # only will match if everything is okay, but lets be
-            # explicit about it
-            branch_rev = self.b1.repository.get_revision(cset_rev.revision_id)
+        open(',,bundle', 'wb').write(bundle_txt.getvalue())
+        bundle_txt.seek(0)
+        # This should also validate the generated bundle 
+        bundle = BundleReader(bundle_txt)
+        repository = self.b1.repository
+        for bundle_rev in bundle.info.real_revisions:
+            # These really should have already been checked when we read the
+            # bundle, since it computes the sha1 hash for the revision, which
+            # only will match if everything is okay, but lets be explicit about
+            # it
+            branch_rev = repository.get_revision(bundle_rev.revision_id)
             for a in ('inventory_sha1', 'revision_id', 'parent_ids',
                       'timestamp', 'timezone', 'message', 'committer', 
                       'parent_ids', 'properties'):
-                self.assertEqual(getattr(branch_rev, a), getattr(cset_rev, a))
-            self.assertEqual(len(branch_rev.parent_ids), len(cset_rev.parent_ids))
+                self.assertEqual(getattr(branch_rev, a), 
+                                 getattr(bundle_rev, a))
+            self.assertEqual(len(branch_rev.parent_ids), 
+                             len(bundle_rev.parent_ids))
         self.assertEqual(rev_ids, 
-                         [r.revision_id for r in cset.info.real_revisions])
-        self.valid_apply_changeset(base_rev_id, cset,
+                         [r.revision_id for r in bundle.info.real_revisions])
+        self.valid_apply_bundle(base_rev_id, bundle,
                                    checkout_dir=checkout_dir)
 
-        return cset
+        return bundle
 
-    def get_invalid_cset(self, base_rev_id, rev_id):
-        """Create a changeset from base_rev_id -> rev_id in built-in branch.
+    def get_invalid_bundle(self, base_rev_id, rev_id):
+        """Create a bundle from base_rev_id -> rev_id in built-in branch.
         Munge the text so that it's invalid.
         
-        :return: The in-memory changeset
+        :return: The in-memory bundle
         """
         from cStringIO import StringIO
 
-        cset_txt = StringIO()
-        rev_ids = write_changeset(self.b1.repository, rev_id, base_rev_id, 
-                                  cset_txt)
-        cset_txt.seek(0)
-        open(',,cset', 'wb').write(cset_txt.getvalue())
-        cset_txt.seek(0)
-        new_text = cset_txt.getvalue().replace('executable:no', 
+        bundle_txt = StringIO()
+        rev_ids = write_bundle(self.b1.repository, rev_id, base_rev_id, 
+                               bundle_txt)
+        bundle_txt.seek(0)
+        open(',,bundle', 'wb').write(bundle_txt.getvalue())
+        bundle_txt.seek(0)
+        new_text = bundle_txt.getvalue().replace('executable:no', 
                                                'executable:yes')
-        cset_txt = StringIO(new_text)
-        cset = ChangesetReader(cset_txt)
-        self.valid_apply_changeset(base_rev_id, cset)
-        return cset
+        bundle_txt = StringIO(new_text)
+        bundle = BundleReader(bundle_txt)
+        self.valid_apply_bundle(base_rev_id, bundle)
+        return bundle 
 
     def get_checkout(self, rev_id, checkout_dir=None):
         """Get a new tree, with the specified revision in it.
@@ -373,9 +378,9 @@
                 os.mkdir(checkout_dir)
         tree = BzrDir.create_standalone_workingtree(checkout_dir)
         s = StringIO()
-        ancestors = write_changeset(self.b1.repository, rev_id, None, s)
+        ancestors = write_bundle(self.b1.repository, rev_id, None, s)
         s.seek(0)
-        install_changeset(tree.branch.repository, ChangesetReader(s))
+        install_bundle(tree.branch.repository, BundleReader(s))
         for ancestor in ancestors:
             old = self.b1.repository.revision_tree(ancestor)
             new = tree.branch.repository.revision_tree(ancestor)
@@ -394,7 +399,7 @@
             tree.update()
         return tree
 
-    def valid_apply_changeset(self, base_rev_id, reader, checkout_dir=None):
+    def valid_apply_bundle(self, base_rev_id, reader, checkout_dir=None):
         """Get the base revision, apply the changes, and make
         sure everything matches the builtin branch.
         """
@@ -404,13 +409,13 @@
         info = reader.info
         for rev in info.real_revisions:
             self.assert_(not repository.has_revision(rev.revision_id),
-                'Revision {%s} present before applying changeset' 
+                'Revision {%s} present before applying bundle' 
                 % rev.revision_id)
-        merge_changeset(reader, to_tree, True, Merge3Merger, False, False)
+        merge_bundle(reader, to_tree, True, Merge3Merger, False, False)
 
         for rev in info.real_revisions:
             self.assert_(repository.has_revision(rev.revision_id),
-                'Missing revision {%s} after applying changeset' 
+                'Missing revision {%s} after applying bundle' 
                 % rev.revision_id)
 
         self.assert_(to_tree.branch.repository.has_revision(info.target))
@@ -443,7 +448,7 @@
             # self.assertEqual(base_tree.get_file(fileid).read(),
             #         to_tree.get_file(fileid).read())
 
-    def test_changeset(self):
+    def test_bundle(self):
 
         import os, sys
         pjoin = os.path.join
@@ -455,8 +460,8 @@
         self.tree1.add('one')
         self.tree1.commit('add one', rev_id='a@cset-0-1')
 
-        cset = self.get_valid_cset(None, 'a@cset-0-1')
-        cset = self.get_valid_cset(None, 'a@cset-0-1',
+        bundle = self.get_valid_bundle(None, 'a@cset-0-1')
+        bundle = self.get_valid_bundle(None, 'a@cset-0-1',
                 message='With a specialized message')
 
         # Make sure we can handle files with spaces, tabs, other
@@ -492,10 +497,10 @@
                 ])
         self.tree1.commit('add whitespace', rev_id='a@cset-0-2')
 
-        cset = self.get_valid_cset('a@cset-0-1', 'a@cset-0-2')
+        bundle = self.get_valid_bundle('a@cset-0-1', 'a@cset-0-2')
 
-        # Check a rollup changeset
-        cset = self.get_valid_cset(None, 'a@cset-0-2')
+        # Check a rollup bundle 
+        bundle = self.get_valid_bundle(None, 'a@cset-0-2')
 
         # Now delete entries
         self.tree1.remove(
@@ -509,20 +514,20 @@
         tt.apply()
         self.tree1.commit('removed', rev_id='a@cset-0-3')
         
-        cset = self.get_valid_cset('a@cset-0-2', 'a@cset-0-3')
-        self.assertRaises(TestamentMismatch, self.get_invalid_cset, 
+        bundle = self.get_valid_bundle('a@cset-0-2', 'a@cset-0-3')
+        self.assertRaises(TestamentMismatch, self.get_invalid_bundle, 
                           'a@cset-0-2', 'a@cset-0-3')
-        # Check a rollup changeset
-        cset = self.get_valid_cset(None, 'a@cset-0-3')
+        # Check a rollup bundle 
+        bundle = self.get_valid_bundle(None, 'a@cset-0-3')
 
 
         # Now move the directory
         self.tree1.rename_one('dir', 'sub/dir')
         self.tree1.commit('rename dir', rev_id='a@cset-0-4')
 
-        cset = self.get_valid_cset('a@cset-0-3', 'a@cset-0-4')
-        # Check a rollup changeset
-        cset = self.get_valid_cset(None, 'a@cset-0-4')
+        bundle = self.get_valid_bundle('a@cset-0-3', 'a@cset-0-4')
+        # Check a rollup bundle 
+        bundle = self.get_valid_bundle(None, 'a@cset-0-4')
 
         # Modified files
         open('b1/sub/dir/WithCaps.txt', 'ab').write('\nAdding some text\n')
@@ -531,7 +536,7 @@
         self.tree1.rename_one('sub/dir/trailing space ', 
                               'sub/ start and end space ')
         self.tree1.commit('Modified files', rev_id='a@cset-0-5')
-        cset = self.get_valid_cset('a@cset-0-4', 'a@cset-0-5')
+        bundle = self.get_valid_bundle('a@cset-0-4', 'a@cset-0-5')
 
         # Handle international characters
         f = open(u'b1/with Dod\xe9', 'wb')
@@ -544,22 +549,22 @@
         self.tree1.commit(u'i18n commit from William Dod\xe9', 
                           rev_id='a@cset-0-6', committer=u'William Dod\xe9',
                           verbose=False)
-        cset = self.get_valid_cset('a@cset-0-5', 'a@cset-0-6')
+        bundle = self.get_valid_bundle('a@cset-0-5', 'a@cset-0-6')
         self.tree1.rename_one('sub/dir/WithCaps.txt', 'temp')
         self.tree1.rename_one('with space.txt', 'WithCaps.txt')
         self.tree1.rename_one('temp', 'with space.txt')
         self.tree1.commit(u'swap filenames', rev_id='a@cset-0-7',
                           verbose=False)
-        cset = self.get_valid_cset('a@cset-0-6', 'a@cset-0-7')
+        bundle = self.get_valid_bundle('a@cset-0-6', 'a@cset-0-7')
         other = self.get_checkout('a@cset-0-6')
         other.rename_one('sub/dir/nolastnewline.txt', 'sub/nolastnewline.txt')
         other.commit('rename file', rev_id='a@cset-0-7b')
         merge([other.basedir, -1], [None, None], this_dir=self.tree1.basedir)
         self.tree1.commit(u'Merge', rev_id='a@cset-0-8',
                           verbose=False)
-        cset = self.get_valid_cset('a@cset-0-7', 'a@cset-0-8')
+        bundle = self.get_valid_bundle('a@cset-0-7', 'a@cset-0-8')
 
-    def test_symlink_cset(self):
+    def test_symlink_bundle(self):
         if not has_symlinks():
             raise TestSkipped("No symlink support")
         self.tree1 = BzrDir.create_standalone_workingtree('b1')
@@ -568,7 +573,7 @@
         tt.new_symlink('link', tt.root, 'bar/foo', 'link-1')
         tt.apply()
         self.tree1.commit('add symlink', rev_id='l@cset-0-1')
-        self.get_valid_cset(None, 'l@cset-0-1')
+        self.get_valid_bundle(None, 'l@cset-0-1')
         tt = TreeTransform(self.tree1)
         trans_id = tt.trans_id_tree_file_id('link-1')
         tt.adjust_path('link2', tt.root, trans_id)
@@ -576,22 +581,22 @@
         tt.create_symlink('mars', trans_id)
         tt.apply()
         self.tree1.commit('rename and change symlink', rev_id='l@cset-0-2')
-        self.get_valid_cset('l@cset-0-1', 'l@cset-0-2')
+        self.get_valid_bundle('l@cset-0-1', 'l@cset-0-2')
         tt = TreeTransform(self.tree1)
         trans_id = tt.trans_id_tree_file_id('link-1')
         tt.delete_contents(trans_id)
         tt.create_symlink('jupiter', trans_id)
         tt.apply()
         self.tree1.commit('just change symlink target', rev_id='l@cset-0-3')
-        self.get_valid_cset('l@cset-0-2', 'l@cset-0-3')
+        self.get_valid_bundle('l@cset-0-2', 'l@cset-0-3')
         tt = TreeTransform(self.tree1)
         trans_id = tt.trans_id_tree_file_id('link-1')
         tt.delete_contents(trans_id)
         tt.apply()
         self.tree1.commit('Delete symlink', rev_id='l@cset-0-4')
-        self.get_valid_cset('l@cset-0-3', 'l@cset-0-4')
+        self.get_valid_bundle('l@cset-0-3', 'l@cset-0-4')
 
-    def test_binary_cset(self):
+    def test_binary_bundle(self):
         self.tree1 = BzrDir.create_standalone_workingtree('b1')
         self.b1 = self.tree1.branch
         tt = TreeTransform(self.tree1)
@@ -599,13 +604,13 @@
         tt.new_file('file2', tt.root, '\x00\xff', 'binary-2')
         tt.apply()
         self.tree1.commit('add binary', rev_id='b@cset-0-1')
-        self.get_valid_cset(None, 'b@cset-0-1')
+        self.get_valid_bundle(None, 'b@cset-0-1')
         tt = TreeTransform(self.tree1)
         trans_id = tt.trans_id_tree_file_id('binary-1')
         tt.delete_contents(trans_id)
         tt.apply()
         self.tree1.commit('delete binary', rev_id='b@cset-0-2')
-        self.get_valid_cset('b@cset-0-1', 'b@cset-0-2')
+        self.get_valid_bundle('b@cset-0-1', 'b@cset-0-2')
         tt = TreeTransform(self.tree1)
         trans_id = tt.trans_id_tree_file_id('binary-2')
         tt.adjust_path('file3', tt.root, trans_id)
@@ -613,14 +618,14 @@
         tt.create_file('filecontents\x00', trans_id)
         tt.apply()
         self.tree1.commit('rename and modify binary', rev_id='b@cset-0-3')
-        self.get_valid_cset('b@cset-0-2', 'b@cset-0-3')
+        self.get_valid_bundle('b@cset-0-2', 'b@cset-0-3')
         tt = TreeTransform(self.tree1)
         trans_id = tt.trans_id_tree_file_id('binary-2')
         tt.delete_contents(trans_id)
         tt.create_file('\x00filecontents', trans_id)
         tt.apply()
         self.tree1.commit('just modify binary', rev_id='b@cset-0-4')
-        self.get_valid_cset('b@cset-0-3', 'b@cset-0-4')
+        self.get_valid_bundle('b@cset-0-3', 'b@cset-0-4')
 
     def test_last_modified(self):
         self.tree1 = BzrDir.create_standalone_workingtree('b1')
@@ -648,4 +653,4 @@
         self.tree1.commit(u'Merge', rev_id='a@lmod-0-3',
                           verbose=False)
         self.tree1.commit(u'Merge', rev_id='a@lmod-0-4')
-        cset = self.get_valid_cset('a@lmod-0-2a', 'a@lmod-0-4')
+        bundle = self.get_valid_bundle('a@lmod-0-2a', 'a@lmod-0-4')

=== modified file 'setup.py'
--- setup.py	2006-05-20 19:31:52 +0000
+++ setup.py	2006-05-30 15:18:12 +0000
@@ -112,8 +112,8 @@
                 'bzrlib.util.elementtree',
                 'bzrlib.util.effbot.org',
                 'bzrlib.util.configobj',
-                'bzrlib.changeset',
-                'bzrlib.changeset.serializer'
+                'bzrlib.bundle',
+                'bzrlib.bundle.serializer'
                 ],
       scripts=['bzr'],
       cmdclass={'install_scripts': my_install_scripts, 'build': bzr_build},

